import * as Cesium from 'cesium'
export class CesiumViewerManager {
    private static _viewer: Cesium.Viewer | null = null;

    /**
     * 初始化 Viewer 实例
     * @param container 容器的 DOM ID
     * @param options 可选配置参数
     * @returns 返回 Cesium.Viewer 实例
     */
    public static initViewer(container: string, options?: object): Cesium.Viewer {
        if (!this._viewer) {
            this._viewer = new Cesium.Viewer(container, options);
        }
        return this._viewer;
    }

    /**
     * 获取 Viewer 实例
     * @returns 返回 Cesium.Viewer 实例或 null
     */
    public static getViewer(): Cesium.Viewer | null {
        return this._viewer;
    }

    /**
     * 销毁 Viewer 实例
     */
    public static destroyViewer(): void {
        if (this._viewer) {
            this._viewer.destroy();
            this._viewer = null;
        }
    }
}
